//
// FILE:     CellTest.java
// AUTHOR:   Eugene Wallingford 
// DATE:     2012/10/10
// COMMENT:  This incomplete test case demonstrates most of the interface
//           and behavior of the Cell object.
//
// MODIFIED: 2012/10/13 -- Eugene Wallingford
// CHANGE:   added tests for isWin()
//
// MODIFIED: 2012/10/17 -- Eugene Wallingford
// CHANGE:   changed name of isWin() to isStraight()
//

import junit.framework.TestCase;

public class CellTest extends TestCase {
  
  public void testTwoCellsTwoDifferentRightMoves() {
    Cell c = new Cell();
    Cell r = new Cell();
    c.accept( 'r', r );
    c.move( 'r', 'x' );
    c.move( 'r', 'o' );
    assertEquals( "[o][x]", c.display( 'r' ) );
  }
  
  public void testTwoCellsThreeDifferentLeftMoves() {
    Cell cell = new Cell();
    Cell left = new Cell();
    cell.accept( 'L', left );
    cell.move( 'L', 'x' );
    cell.move( 'L', 'x' );
    cell.move( 'L', 'o' );
    assertEquals( "[o][x]", cell.display( 'L' ) );
  }
  
  public void testThreeCellsThreeDifferentRightMoves() {
    Cell left = new Cell();
    Cell mid  = new Cell();
    Cell end  = new Cell();
    left.accept( 'R', mid );
     mid.accept( 'R', end );
    left.move( 'R', 'o' );
    assertEquals( "[o][ ][ ]", left.display( 'R' ) );
    left.move( 'R', 'o' );
    assertEquals( "[o][o][ ]", left.display( 'R' ) );
    left.move( 'R', 'x' );
    assertEquals( "[x][o][o]", left.display( 'R' ) );
  }
  
  public void testPositionIsLoss() {
    Cell left = new Cell();
    Cell mid  = new Cell();
    Cell end  = new Cell();
    left.accept( 'R', mid );
     mid.accept( 'R', end );
     
    left.move( 'R', 'o' );
    assertFalse( left.isStraight( 'R' ) );
    
    left.move( 'R', 'o' );
    assertFalse( left.isStraight( 'R' ) );
    
    left.move( 'R', 'x' );
    assertFalse( left.isStraight( 'R' ) );
  }
  
  public void testPositionIsStraight() {
    Cell left = new Cell();
    Cell mid  = new Cell();
    Cell end  = new Cell();
    left.accept( 'R', mid );
     mid.accept( 'R', end );
     
    left.move( 'R', 'o' );
    assertFalse( left.isStraight( 'R' ) );
    
    left.move( 'R', 'o' );
    assertFalse( left.isStraight( 'R' ) );
    
    left.move( 'R', 'o' );
    assertTrue( left.isStraight( 'R' ) );
  }
}
